@@ -1,10 +1,7 @@
 # inspired by:
 # https://github.com/scikit-learn/scikit-learn/blob/master/sklearn/tests/test_base.py
-from abc import ABCMeta
 
 import numpy as np
-
-# noinspection PyPackageRequirements
 import scipy.sparse as sp
 from numpy.testing import assert_array_equal, assert_raises
 from sklearn import clone
@@ -13,13 +10,10 @@ from sklearn.model_selection import GridSearchCV
 from sklearn.pipeline import Pipeline
 
 import sklearndf
-from sklearndf import EstimatorDF
-
-# noinspection PyProtectedMember
-from sklearndf._wrapper import _EstimatorWrapperDF, df_estimator
 from sklearndf.classification import SVCDF, DecisionTreeClassifierDF
 from sklearndf.pipeline import PipelineDF
 from sklearndf.transformation import OneHotEncoderDF
+from sklearndf.wrapper import make_df_estimator
 
 
 class _DummyEstimator(BaseEstimator):
@@ -40,19 +34,9 @@ class _DummyEstimator3(BaseEstimator):
         self.d = d
 
 
-@df_estimator(df_wrapper_type=_EstimatorWrapperDF)
-class _DummyEstimatorDF(EstimatorDF, _DummyEstimator, metaclass=ABCMeta):
-    pass
-
-
-@df_estimator(df_wrapper_type=_EstimatorWrapperDF)
-class _DummyEstimator2DF(EstimatorDF, _DummyEstimator2, metaclass=ABCMeta):
-    pass
-
-
-@df_estimator(df_wrapper_type=_EstimatorWrapperDF)
-class _DummyEstimator3DF(EstimatorDF, _DummyEstimator3, metaclass=ABCMeta):
-    pass
+_DummyEstimatorDF = make_df_estimator(_DummyEstimator)
+_DummyEstimator2DF = make_df_estimator(_DummyEstimator2)
+_DummyEstimator3DF = make_df_estimator(_DummyEstimator3)
 
 
 def test_clone() -> None:
@@ -166,6 +150,7 @@ def test_get_params() -> None:
     assert "a__d" in test.get_params(deep=True)
     assert "a__d" not in test.get_params(deep=False)
 
+    # noinspection PyTypeChecker
     test.set_params(a__d=2)
     assert test.a.d == 2
     assert_raises(ValueError, test.set_params, a__a=2)
